==> 0.1.7.tar.gz: lib/pages/home/slock/record/LockRecord.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_easyloading/flutter_easyloading.dart';
import 'package:witsystem_core/error/NetError.dart';
import 'package:witsystem_core/user/UserRemarks.dart';
import 'package:witsystem_device_manage/assets/icons/WitsIcon.dart';
import 'package:witsystem_device_manage/generated/l10n.dart';
import 'package:witsystem_device_plugin/device/DeviceManage.dart';

///开锁记录

class LockRecordWidget extends StatefulWidget {
  final String deviceName;
  final String deviceId;

  const LockRecordWidget(
      {Key? key, required this.deviceName, required this.deviceId})
      : super(key: key);

  @override
  State<StatefulWidget> createState() {
    return RecordState();
  }
}

class RecordState extends State<LockRecordWidget> {
  final ScrollController _controller =  ScrollController();
  List<dynamic> list = [];
  int _page = 0;

  @override
  void initState() {
    super.initState();
    init();
    _controller.addListener(_loading);

  }

  //初始化数据
  init({bool isShow = true}) async {
    if (isShow) {
      EasyLoading.show(
          status: S.current.device_loading,
          maskType: EasyLoadingMaskType.clear);
    }
    try{
      List<dynamic> lockRecord =
      await DeviceManage().lockRecord(widget.deviceId, _page);
      if (lockRecord.isEmpty) {
        EasyLoading.dismiss();
        EasyLoading.showToast(S.current.device_noData);
        return;
      }
      await _handler(lockRecord);
      EasyLoading.dismiss();
      //EasyLoading.showToast(S.current.device_success);
      setState(() {});
    }on PlatformException catch(e){
      EasyLoading.dismiss();
      var error = NetError.error(int.parse(e.code));
      EasyLoading.showToast(S.current.device_fail(error.error));
    }

  }

  ///处理数据，主要是分割日期和时间，和完成备注信息和国际化
  _handler(List<dynamic> lockRecord) async {
    Map? remarksInfo;
    Map<String, List<dynamic>> map = {};
    for (int i = 0; i < lockRecord.length; i++) {
      List<String> split =
          lockRecord[i]["createdTime"].toString().split(" "); //分割日期和时间
      if (map[split[0]] == null) {
        map[split[0]] = [
          {"date": split[0], "widgetType": "title"}
        ];
      }
      remarksInfo = await UserRemarks()
          .getRemarksInfo(lockRecord[i]["userUuid"]); //获得备注信息
      lockRecord[i]["msg"] = S.current.device_unlockRecord(
          //重新组装信息，主要是为了实现国际化
          remarksInfo != null //判断如果有备注就是用备注
              ? remarksInfo["nickName"]
              : lockRecord[i]["msg"].toString().split(" ")[0],
          //没有备注用户服务器返回的msg开头名称
          widget.deviceName,
          lockRecord[i]["state"] == "成功"
              ? S.current.device_success
              : S.current.device_fail(""));
      lockRecord[i]["time"] = split[1];
      map[split[0]]?.add(lockRecord[i]);
    }
    for (var element in map.values) {
      list.addAll(element);
    }
  }

  ///根据开门类型返回不同icon
  Widget _unlockIcon(int index) {
    switch (list[index]["unlockType"]) {
      case 1:
        return Icon(WitsIcon.zhiwen,
            size: 16,
            color: (list[index]["state"] == "成功" ? Colors.blue : Colors.red));
      case 2:
        return Icon(WitsIcon.menka,
            size: 16,
            color: (list[index]["state"] == "成功" ? Colors.blue : Colors.red));
      case 3:
        return Icon(WitsIcon.jianpan,
            size: 16,
            color: (list[index]["state"] == "成功" ? Colors.blue : Colors.red));
      case 4:
        return Icon(WitsIcon.renlian,
            size: 16,
            color: (list[index]["state"] == "成功" ? Colors.blue : Colors.red));
      case 5:
        return Icon(WitsIcon.yaokongqi,
            size: 16,
            color: (list[index]["state"] == "成功" ? Colors.blue : Colors.red));
      case 6:
        return Icon(WitsIcon.lanya,
            size: 16,
            color: (list[index]["state"] == "成功" ? Colors.blue : Colors.red));
      case 7:
        return Icon(WitsIcon.yuancheng,
            size: 16,
            color: (list[index]["state"] == "成功" ? Colors.blue : Colors.red));
      default:
        return Icon(Icons.lock_outlined,
            size: 16,
            color: (list[index]["state"] == "成功" ? Colors.blue : Colors.red));
    }
  }

  ///加载
  _loading(){
    if (_controller.position.pixels == _controller.position.maxScrollExtent) {
      _page++;
      init();
    }
  }

  ///刷新
  Future<void> _refresh() async {
    _page = 0;
    list.clear();
    await init(isShow: false);
    return Future.value(null);
  }

  @override
  void dispose() {
    super.dispose();
    _controller.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text(S.of(context).device_LockRecord + "(${widget.deviceName})",
            style: const TextStyle(fontSize: 16)),
      ),
      body: SizedBox(
        height: double.infinity,
        width: double.infinity,
        child: RefreshIndicator(
          onRefresh: _refresh,
          child: ListView.builder(
            controller: _controller,
            itemCount: list.length,
            physics: const AlwaysScrollableScrollPhysics(),
            itemBuilder: (context, index) {
              return list[index]["widgetType"] != null
                  ? Column(
                      crossAxisAlignment: CrossAxisAlignment.start,
                      children: [
                        Container(
                          width: 2,
                          height: index > 0 ? 40 : 0,
                          margin: const EdgeInsets.fromLTRB(125, 0, 0, 0),
                          color: Colors.blue,
                        ),
                        Row(
                          children: [
                            Container(
                              width: 100,
                              alignment: Alignment.centerRight,
                              child: Text(list[index]["date"],
                                  style: const TextStyle(fontSize: 18)),
                            ),
                            Container(
                              width: 30,
                              height: 30,
                              margin: const EdgeInsets.fromLTRB(10, 0, 0, 0),
                              decoration: const BoxDecoration(
                                  color: Colors.blue,
                                  borderRadius:
                                      BorderRadius.all(Radius.circular(15))),
                            ),
                          ],
                        )
                      ],
                    )
                  : Column(
                      crossAxisAlignment: CrossAxisAlignment.start,
                      children: [
                        Container(
                          width: 2,
                          height: 40,
                          margin: const EdgeInsets.fromLTRB(125, 0, 0, 0),
                          color: Colors.blue,
                        ),
                        Row(
                          crossAxisAlignment: CrossAxisAlignment.center,
                          children: [
                            Container(
                              width: 100,
                              alignment: Alignment.centerRight,
                              child: Text(list[index]["time"]),
                            ),
                            Container(
                              width: 30,
                              height: 30,
                              alignment: Alignment.center,
                              margin: const EdgeInsets.fromLTRB(10, 0, 10, 0),
                              decoration: BoxDecoration(
                                  borderRadius: const BorderRadius.all(
                                      Radius.circular(15)),
                                  border: Border.all(
                                    color: (list[index]["state"] == "成功"
                                        ? Colors.blue
                                        : Colors.red),
                                  )),
                              child: _unlockIcon(index),
                            ),
                            Expanded(
                              child: Text(
                                "${list[index]["msg"]}",
                                style: const TextStyle(fontSize: 12),
                              ),
                            ),
                          ],
                        )
                      ],
                    );
            },
          ),
        ),
      ),
    );
  }
}

==> 0.2.8.tar.gz: lib/pages/home/slock/record/LockRecord.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_easyloading/flutter_easyloading.dart';
import 'package:witsystem_core/error/NetError.dart';
import 'package:witsystem_core/user/UserRemarks.dart';
import 'package:witsystem_device_manage/assets/icons/WitsIcon.dart';
import 'package:witsystem_device_manage/generated/l10n.dart';
import 'package:witsystem_device_plugin/device/DeviceManage.dart';

///开锁记录

class LockRecordWidget extends StatefulWidget {
  final String deviceId;

  const LockRecordWidget(
      {Key? key,  required this.deviceId})
      : super(key: key);

  @override
  State<StatefulWidget> createState() {
    return RecordState();
  }
}

class RecordState extends State<LockRecordWidget> {
  String deviceName="";
  final ScrollController _controller =  ScrollController();
  List<dynamic> list = [];
  int _page = 0;

  @override
  void initState() {
    super.initState();
    _getDeviceName();
    init();
    _controller.addListener(_loading);

  }
  ///获得设备名称
  _getDeviceName() async {
    deviceName=  (await DeviceManage().device(widget.deviceId))!["deviceName"];
    setState(() {});
  }


  ///初始化数据
  init({bool isShow = true}) async {
    if (isShow) {
      EasyLoading.show(
          status: S.current.device_loading,
          maskType: EasyLoadingMaskType.clear);
    }
    try{
      List<dynamic> lockRecord =
      await DeviceManage().lockRecord(widget.deviceId, _page);
      if (lockRecord.isEmpty) {
        EasyLoading.dismiss();
        EasyLoading.showToast(S.current.device_noData);
        return;
      }
      await _handler(lockRecord);
      EasyLoading.dismiss();
      //EasyLoading.showToast(S.current.device_success);
      setState(() {});
    }on PlatformException catch(e){
      EasyLoading.dismiss();
      var error = NetError.error(int.parse(e.code));
      EasyLoading.showToast(S.current.device_fail(error.error));
    }

  }

  ///处理数据，主要是分割日期和时间，和完成备注信息和国际化
  _handler(List<dynamic> lockRecord) async {
    Map? remarksInfo;
    Map<String, List<dynamic>> map = {};
    for (int i = 0; i < lockRecord.length; i++) {
      List<String> split =
          lockRecord[i]["createdTime"].toString().split(" "); //分割日期和时间
      if (map[split[0]] == null) {
        map[split[0]] = [
          {"date": split[0], "widgetType": "title"}
        ];
      }
      remarksInfo = await UserRemarks()
          .getRemarksInfo(lockRecord[i]["userUuid"]); //获得备注信息
      lockRecord[i]["msg"] = S.current.device_unlockRecord(
          //重新组装信息，主要是为了实现国际化
          remarksInfo != null //判断如果有备注就是用备注
              ? remarksInfo["nickName"]
              : lockRecord[i]["msg"].toString().split(" ")[0],
          //没有备注用户服务器返回的msg开头名称
          deviceName,
          lockRecord[i]["state"] == "成功"
              ? S.current.device_success
              : S.current.device_fail(""));
      lockRecord[i]["time"] = split[1];
      map[split[0]]?.add(lockRecord[i]);
    }
    for (var element in map.values) {
      list.addAll(element);
    }
  }

  ///根据开门类型返回不同icon
  Widget _unlockIcon(int index) {
    switch (list[index]["unlockType"]) {
      case 1:
        return Icon(WitsIcon.zhiwen,
            size: 16,
            color: (list[index]["state"] == "成功" ? Colors.blue : Colors.red));
      case 2:
        return Icon(WitsIcon.menka,
            size: 16,
            color: (list[index]["state"] == "成功" ? Colors.blue : Colors.red));
      case 3:
        return Icon(WitsIcon.jianpan,
            size: 16,
            color: (list[index]["state"] == "成功" ? Colors.blue : Colors.red));
      case 4:
        return Icon(WitsIcon.renlian,
            size: 16,
            color: (list[index]["state"] == "成功" ? Colors.blue : Colors.red));
      case 5:
        return Icon(WitsIcon.yaokongqi,
            size: 16,
            color: (list[index]["state"] == "成功" ? Colors.blue : Colors.red));
      case 6:
        return Icon(WitsIcon.lanya,
            size: 16,
            color: (list[index]["state"] == "成功" ? Colors.blue : Colors.red));
      case 7:
        return Icon(WitsIcon.yuancheng,
            size: 16,
            color: (list[index]["state"] == "成功" ? Colors.blue : Colors.red));
      default:
        return Icon(Icons.lock_outlined,
            size: 16,
            color: (list[index]["state"] == "成功" ? Colors.blue : Colors.red));
    }
  }

  ///加载
  _loading(){
    if (_controller.position.pixels == _controller.position.maxScrollExtent) {
      _page++;
      init();
    }
  }

  ///刷新
  Future<void> _refresh() async {
    _page = 0;
    list.clear();
    await init(isShow: false);
    return Future.value(null);
  }

  @override
  void dispose() {
    super.dispose();
    _controller.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text(S.of(context).device_LockRecord + "($deviceName)",
            style: const TextStyle(fontSize: 16)),
      ),
      body: SizedBox(
        height: double.infinity,
        width: double.infinity,
        child: RefreshIndicator(
          onRefresh: _refresh,
          child: ListView.builder(
            controller: _controller,
            itemCount: list.length,
            physics: const AlwaysScrollableScrollPhysics(),
            itemBuilder: (context, index) {
              return list[index]["widgetType"] != null
                  ? Column(
                      crossAxisAlignment: CrossAxisAlignment.start,
                      children: [
                        Container(
                          width: 2,
                          height: index > 0 ? 40 : 0,
                          margin: const EdgeInsets.fromLTRB(125, 0, 0, 0),
                          color: Colors.blue,
                        ),
                        Row(
                          children: [
                            Container(
                              width: 100,
                              alignment: Alignment.centerRight,
                              child: Text(list[index]["date"],
                                  style: const TextStyle(fontSize: 18)),
                            ),
                            Container(
                              width: 30,
                              height: 30,
                              margin: const EdgeInsets.fromLTRB(10, 0, 0, 0),
                              decoration: const BoxDecoration(
                                  color: Colors.blue,
                                  borderRadius:
                                      BorderRadius.all(Radius.circular(15))),
                            ),
                          ],
                        )
                      ],
                    )
                  : Column(
                      crossAxisAlignment: CrossAxisAlignment.start,
                      children: [
                        Container(
                          width: 2,
                          height: 40,
                          margin: const EdgeInsets.fromLTRB(125, 0, 0, 0),
                          color: Colors.blue,
                        ),
                        Row(
                          crossAxisAlignment: CrossAxisAlignment.center,
                          children: [
                            Container(
                              width: 100,
                              alignment: Alignment.centerRight,
                              child: Text(list[index]["time"]),
                            ),
                            Container(
                              width: 30,
                              height: 30,
                              alignment: Alignment.center,
                              margin: const EdgeInsets.fromLTRB(10, 0, 10, 0),
                              decoration: BoxDecoration(
                                  borderRadius: const BorderRadius.all(
                                      Radius.circular(15)),
                                  border: Border.all(
                                    color: (list[index]["state"] == "成功"
                                        ? Colors.blue
                                        : Colors.red),
                                  )),
                              child: _unlockIcon(index),
                            ),
                            Expanded(
                              child: Text(
                                "${list[index]["msg"]}",
                                style: const TextStyle(fontSize: 12),
                              ),
                            ),
                          ],
                        )
                      ],
                    );
            },
          ),
        ),
      ),
    );
  }
}
